/****************************************************************************
 Include Section
*****************************************************************************/

/*****************************************************************************
 Symbolic constants / definitions
******************************************************************************/

#define RDAC_STEP_VALUE_110 0x37 /* Digipot step value 0x37 gives us 1.10V */
#define RDAC_STEP_VALUE_115 0x2D /* Digipot step value 0x2D gives us 1.15V */
#define RDAC_STEP_VALUE_120 0x23 /* Digipot step value 0x23 gives us 1.20V */
#define RDAC_STEP_VALUE_125 0x1A /* Digipot step value 0x1A gives us 1.25V */
#define RDAC_STEP_VALUE_130 0x12 /* Digipot step value 0x12 gives us 1.30V */
#define RDAC_STEP_VALUE_135 0x0A /* Digipot step value 0x0A gives us 1.35V */
#define RDAC_STEP_VALUE_140 0x03 /* Digipot step value 0x03 gives us 1.40V */


/*****************************************************************************
 Dynamic Power Managment
*****************************************************************************/

/*************************************************
* To activate PLL and Voltage Regulator settings *
* uncomment the following definition             *
*************************************************/

//#define __ACTIVATE_DPM__


/********************************
* PLL Control Register Value    *
* Reset = 0x0A00                *
* ADSP-BF592-A EZ-KIT Lite:     *
* CLKIN = 25MHz                 *
* MSEL = 12                     *
* --> VCO = 25MHz x 12 = 300MHz *
********************************/

#define PLL_CTL_VAL             (\
                               nBYPASS              |   /* Bypass the PLL */\
                               nOUT_DELAY           |   /* Add 200ps Delay To EBIU Output Signals */\
                               nIN_DELAY            |   /* Add 200ps Delay To EBIU Input Latches */\
                               nPDWN                |   /* Enter Deep Sleep Mode */\
                               nSTOPCK              |   /* Core Clock Off */\
                               nPLL_OFF             |   /* PLL Not Powered */\
                               nDF                  |   /* 0: PLL = CLKIN, 1: PLL = CLKIN/2 */\
                                SET_MSEL(16)        |   /* Set MSEL = 0-63 --> VCO = CLKIN*MSEL */\
                                0)

#define CLKIN_Hz                 25000000           /* CLKIN [Hz] */
#define VCO_MAX_Hz              400000000           /* VCO [Hz] */
#define VCO_MIN_Hz               50000000           /* VCO [Hz] */


/*********************************
* PLL Divide Register Value      *
* Reset = 0x0004                 *
* ADSP-BF592-A EZ-KIT Lite:      *
* CSEL = 1                       *
* --> CCLK = VCO / CSEL          *
* --> CCLK = 300MHz / 1 = 300MHz *
* SSEL = 4                       *
* --> SCLK = VCO / SSEL          *
* --> SCLK = 300MHz / 4 = 75MHz  *
*********************************/

#define PLL_DIV_VAL             (\
                                SET_SSEL(5)         |   /* Set SSEL = 1-15 --> SCLK = VCO/SSEL */\
                                CSEL_DIV1           |   /* CCLK = VCO / 1 */\
                                0)

#define CCLK_MAX_Hz             VCO_MAX_Hz          /* Maximum Core Clock [Hz] */
#define SCLK_MAX_Hz             80000000            /* Maximum System Clock [Hz] */


/********************************
* PLL Lock Count Register Value *
* Reset = 0x0200                *
********************************/

#define PLL_LOCKCNT_VAL         0x0200


/****************************
* PLL Status Register Value *
* Reset = 0x00A2            *
****************************/

#define PLL_STAT_VAL            (\
                                VSTAT               |   /* Voltage Regulator Status: Regulator at programmed voltage */\
                                PLL_LOCKED          |   /* PLL Locked Status */\
                               nACTIVE_PLLDISABLED  |   /* Active Mode With PLL Disabled */\
                                FULL_ON             |   /* Full-On Mode */\
                               nACTIVE_PLLENABLED   |   /* Active Mode With PLL Enabled */\
                                0)


/*******************************************
* Voltage Regulator Control Register Value *
* Reset = 0x70B0                           *
*******************************************/

#define VR_CTL_VAL              (\
                               nSCKELOW         |   /* Enable Drive CKE Low During Reset */\
                               nWAKE            |   /* Enable RTC/Reset Wakeup From Hibernate */\
                               nPHYWE           |   /* Enable PHY Wakeup From Hibernate */\
                                CLKBUFOE        |   /* CLKIN Buffer Output Enable */\
                                0x00B0          |   /* Bits #7,6 set by default */\
                                FREQ            |   /* FREQ=00 indicates hibernate. FREQ=11 indicates non-Hibernate */\
                                0)


/*****************************
* External Voltage Regulator *
* Digipot Value              *
*****************************/

#define RDAC_STEP_VAL           RDAC_STEP_VALUE_140     /* Digipot step value for 1.40V */


/**********************************************************
* BMODE_SPIMEM: Boot from SPI memory                      *
* This definition will modify the SPI_BAUD register value *
* and can in/decrease boot speed                          *
* Boot Rom default: 0x85                                  *
**********************************************************/

#define SPI_BAUD_VAL            0x85


/****************************************************************************
 EOF
*****************************************************************************/
